@@ -65,7 +65,7 @@ c          get cms equivlent mass and 4 momentum
 c          get Lorentz factor of cms
        call cgetlf(Cmsp,  gc)
 c          boost pj into cms.
-       call cbst0(1, gc, Pjlab, Pjcms)       
+       call cbst0(1, gc, Pjlab, Pjcms)     
 c            boost target into cms
        call cbst0(2, gc, Tglab, Tgcms)
 c          boost proj into target rest system
@@ -73,7 +73,7 @@ c          boost proj into target rest system
            Pjtatr = Pjlab
        else    
            call cbst1(1, Tglab, Pjlab, Pjtatr)       
-       endif    
+       endif
 c            boost target into projectile rest system
        call cbst1(1, Pjlab, Tglab, Tgpatr )
 c            get possible max and min x of leading particles
@@ -423,6 +423,8 @@ c                                         kaon
               p.charge = pj.charge
          else
               p.charge = 0
+              call rndc(u) 
+              p.subcode = pj.subcode
          endif
       elseif(k0 .eq. knuc) then
 c                                        nucleon
