@@ -1645,7 +1645,7 @@ c#################
       end
       subroutine rakekaC(it,to,amss,sqamss,t,p,de)
 c###############
-      real*8  v
+      real*8  v, u
 c############
 c*** sampling of cascade nucleon angle and energy
       ap=akekaC(it,to,amss)
@@ -1654,8 +1654,18 @@ c*** sampling of cascade nucleon angle and energy
       call rndc(v)
       if (v.lt.0.6) ap=ap/6.
     1 continue
-      app=1./ap
-      t=rexpC(app)
+c          below is to produce a random variable t with
+c          exp(-app t)dt. But   this may result in
+c          semi infinite loop when a very small
+c          random number is produced in rexpC.
+c          So the method is replaced by usual one.
+c          K.K 98/03/05
+c      app=1./ap
+c      t=rexpC(app)
+c
+      call rndc(u)
+      t = -ap * log(u)
+c
       t=t + tmin
       if(t.gt.to) go to 1
       p=pofekC(t,it)
