@@ -14,10 +14,16 @@ c	(->   ----------------------------------------------
 	real*8  MinPhotoProdE !1  Below this energy, no photo-prod of hadron.  See also PhotoProd.
 	logical PhotoProd     !1  Switch. if .false., no photo prod. of hadron is considered at all. 
                               !   See also MinPhotoProdE.
-
+        integer Moliere       !2  0--> use all Gaussian approx (with air density change and
+                              !        energy loss effect)
+                              !   1--> use Moliere scattering for non-electrons (default)
+                              !   2--> use Moliere scattering for all charged particles.
+	                      !   If negative, angle correlated displacement is made to be 0
+                              !   since Moliere theory cannot give it. (if >0, we use Gaussian
+                              !   approximation for correlation).
 c	<-)	----------------------------------------------
 
 	common /Zelemagc/  RecoilKineMinE, AnihiE, MaxComptonE,
      *  MaxPhotoE, MinPhotoProdE,   Es, X0, Ecrit, Knockon, 
-     *  PhotoProd
+     *  PhotoProd, Moliere
 
