@@ -1,3 +1,4 @@
+#include "Zmaxdef.h"
 c          common variables used in tracking ptcls.
        integer ToInteract, ToBeObserved, Truncated, Dead,
      *         BorderL,  BorderH
@@ -27,6 +28,7 @@ c                                     (in 'xyz')
        real*8 TargetMassN  ! average target mass number. To be updated
                            ! after a ptcl is moved.
        real*8 TargetAtomicN   ! Average Z of the target.
+       real*8 TargetZ2        ! <Z^2> of the target
        integer TargetNucleonNo  !  target nucleon number at a collision
        integer TargetProtonNo  !  target proton number  //
        integer NumberOfInte ! Number of different kind of interactions 
@@ -34,7 +36,9 @@ c                                     (in 'xyz')
        integer ProcessNo   ! The process really happend is the
                             ! ProcessNo-th process in  IntInfArray.
 	logical ObserveAS     ! made to be T, if AS is to be generated
-
+        logical Upgoing     ! if primary is going upward, made to be t
+        logical UseTbl       ! becomes T, 
+                            ! if length <--> thickness conv. is by table
 	real*8  EminAS      ! minimum energy of e for AS generation.
 	real*8  EasWait     ! for AS generation, must wait until e 
                             ! energy becomes < EasWait
@@ -51,7 +55,13 @@ c                                     (in 'xyz')
 	record /magfield/ Mag
 	integer MaxPtcl
 
-	parameter (MaxPtcl = 8000)   ! max # of ptcls producable in coll.
+	parameter (
+#ifdef MAX_PTCL
+     *     MaxPtcl = MAX_PTCL
+#else
+     *     MaxPtcl = 8000
+#endif
+     *         )   ! max # of ptcls producable in coll.
 	record /ptcl/ Pwork(MaxPtcl)  ! working array to store ptcls.
 	integer Nproduced   ! no. of ptcls produced and stored in Pwork.
 	real*8  MuonPolarization  ! muon polarization value.
@@ -59,12 +69,12 @@ c
        common /Ztrackv/Pwork, IntInfArray, TrackBefMove,
      *  MovedTrack, Offset,
      *  Mag, MuonPolarization,  EminAS, EasWait,
-     *  Zfirst,  TargetMassN, TargetAtomicN,  EnergyLoss, 
-     *  KEmin, KEminCas, Beta, 
-     *  KEmin2, KEminCas2, Ethin, Upsilon, Xai,
+     *  Zfirst,  TargetMassN, TargetAtomicN, TargetZ2,
+     *  EnergyLoss,  KEmin, KEminCas, Beta, 
+     *  KEmin2, KEminCas2, Ethin, Upsilon, Xai, 
      *  ObserveAS, Nproduced, 
      *  MoveStat,  NumberOfInte, ProcessNo, 
-     *  TargetNucleonNo, TargetProtonNo
+     *  TargetNucleonNo, TargetProtonNo, Upgoing, UseTbl
 
 
 
