@@ -8,13 +8,21 @@ c          this is called after primary is fixed.
 #include "Ztrackv.h"
 #include "Zobs.h"
 #include "Zobsp.h"
+#include "Zobsv.h"
+#include "Zatmos.h"
+#include "Zincidentv.h"
+#include "Zearth.h"
 
       external cxyz2prim, cxyz2det
       integer klena, leng
+      real*8  zAngleSave, r1, r2, cosx, lengx
+      real*8 clenbetween2h, cnewcos
       character*70 tracefile
+      data zAngleSave/-1.d30/
+      save zAngleSave
 
       Zfirst = 0.
-
+      Zsave = -1.d30
 c 
       if(Job .eq. 'flesh') then
          call csetEmin(Generate2, KEminObs2, KEmin2, KEminCas2)
@@ -27,20 +35,22 @@ c
 
 
       call cprimxyz   ! compute primary x,y,z axis in 'xyz' system
-      if((Trace .gt. 0 .and. Trace .lt. 60) .or. Trace .gt. 100) then
+      if((Trace .gt. 0 .and. Trace .lt. 60) .or. 
+     *    (Trace .gt. 100 .and. Trace .lt. 160) ) then
 c            default trace output is requested. Open disk file
          write(tracefile, *) TraceDir(1:klena(TraceDir))//'/trace',
      *         EventNo
          call kseblk(tracefile, ' ', leng)
          open(TraceDev, file=tracefile(1:leng), form='formatted')
-      elseif(Trace .gt. 60 .and. Trace .lt. 100) then
+      elseif(Trace .gt. 60 .and. Trace .lt. 100 .or.
+     *       Trace .gt. 160 .and. Trace .lt. 200) then
          call cputCerenkovS     ! cerenkov output header for each event
       endif
 c
       call ciniASObs
-      if(ObsPlane .eq. horizontal ) then
+      if(abs(ObsPlane) .eq. horizontal ) then
          call csetObsZ(cxyz2det)
-      elseif(ObsPlane .eq. perpendicular ) then
+      elseif(abs(ObsPlane) .eq. perpendicular ) then
          call csetObsZ(cxyz2prim)
       elseif(ObsPlane .eq.  notUsed ) then
 c           Nothing to do. observation is at height =
@@ -50,6 +60,24 @@ c           BorderHeighL. (for neutrino)
       endif
 c         check some parameters
       call  cexamParam
+c         if one dimensional and large angle, use table method
+c         for lenth <--> thickness conversion.  make table for that
+      UseTbl = OneDim .eq. 3 .or.
+     *  ( OneDim .eq. 2  .and. 
+     *    abs( AngleAtObsCopy.r(3) ) .lt. 0.5 )
+      UseTbl = UseTbl .and.  .not. Upgoing
+      if(UseTbl .and. zAngleSave .ne. AngleAtObsCopy.r(3) ) then
+         Hbase = HeightList(NoOfSites) - 0.3d0  ! make little bit smaller
+         Htop =100.d3   ! old value was 30d3
+         r1 = Htop + Eradius
+         r2 = Hbase + Eradius
+         lengx = clenbetween2h(r2, r1, -AngleAtObsCopy.r(3))
+         cosx = cnewcos(r2, -AngleAtObsCopy.r(3), lengx)
+         call cl2tTbl(Htop, Hbase, cosx, -AngleAtObsCopy.r(3),
+     *     LenStep, 
+     *     LenTbl, HeightTbl, CosTbl,  ThickTbl, maxl2t, NumStep)
+         zAngleSave = AngleAtObsCopy.r(3)
+      endif
       end
 c     --------- compute primary system, x,y,z.  
 c               The deepest detector is the reference.
@@ -101,7 +129,7 @@ c
 #include "Zobsv.h"
 
       external converter  ! cxyz2prim or cxyz2det
-c                           depending on ObsPlane =2, 1
+c                           depending on |ObsPlane| =2, 1
       integer i
       record /coord/ temp
 c        compute z from the base detector.
