@@ -166,9 +166,9 @@ c                  (at AS generation, some ptcl may have < KEminObs)
                call cobservation(2)
             endif
 c               update observation place
-            if(ObsPlane .eq. horizontal) then
+            if(abs(ObsPlane) .eq. horizontal) then
                cosangle = MovedTrack.vec.coszenith
-            elseif(ObsPlane .eq. perpendicular) then
+            elseif(abs(ObsPlane) .eq. perpendicular) then
                call cscalerProd(MovedTrack.vec.w, DcAtObsXyz,
      *               cosangle)
             else
